betty.ancestry.source module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.source module

Data types to describe information sources.

final class betty.ancestry.source.Source

  Bases: `ShorthandPluginBase`, `HasDate`, `HasFileReferences`, `HasNotes`, `HasLinks`, `HasPrivacy`, `UserFacingEntity`, `Entity`

  A source of information.

  __init__(name: ShorthandStaticTranslations | None = None, *, id: str | None = None, author: ShorthandStaticTranslations | None = None, publisher: ShorthandStaticTranslations | None = None, contained_by: Source | ToZeroOrOneResolver[Source] | ToOneResolver[Source] | None = None, contains: Iterable[Source] | ToManyResolver[Source] | None = None, notes: Iterable[Note] | ToManyResolver[Note] | None = None, date: Datey | None = None, file_references: Iterable['FileReference'] | ToManyResolver['FileReference'] | None = None, links: MutableSequence[Link] | None = None, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None)
  author

    The human-readable author.

  citations

    A bidirectional *-to-many entity type association.

  contained_by

    The source this one is directly contained by.

  contains

    A bidirectional *-to-many entity type association.

  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  property label: Localizable

    The entity’s human-readable label.

  name

    The human-readable source name.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

  publisher

    The human-readable publisher.

  property walk_contains: Iterator[Source]

    All directly and indirectly contained sources.